/*
 * this file specifically keeps track of the subservices and their states,
 * as well as the handlers
 */

#ifndef _STATES_H_
#define _STATES_H_

#include <dbi/dbi.h>

/* only defined from LIBDBI 0.9 and onwards */
#ifndef LIBDBI_VERSION
# define LIBDBI_VERSION ((0 * 10000) + (8 * 100) + 0)
#endif

#include "trap.h"
#include "states.h"

/* connect to the specified database */
dbi_conn db_connect(char *host, char *username, char *password, char *dbname, int port);
/* open the nagios pipe (actually a no-op, but conceptually...) */
int nagios_connect(char *path);

/* return the source code for a module, given its name */
char *get_module(const char *modulename);

/* to quote a string for use in databases,
 * we must have a connection. As in our own
 * processor, we use this to quote lua strings,
 * too.
 */
char *escape(const char *in);

/* save a context into the specified handler id */
int save_context(const char *context, const int handler_id);

/* return a linked list of handlers for the specified oid */
proc_handler *get_handlers(const char *oid);

/* disconnect from the specified database */
int db_disconnect();

/* process the result of executing a trap handler */
int update_state(const proc_result *result);

#endif
